#Summary 

- [PCBA](#section-id-1)
- [Software](#section-id-11)
  - [Debian](#section-id-15)
  - [Other Software](#section-id-49)
  - [Electronic Design Automation (EDA)](#section-id-68)
- [PCB Manufacturing](#section-id-72)
  - [Board Types and Features](#section-id-84)
  - [Copper Layer](#section-id-87)
  - [Soldermask](#section-id-90)
  - [Silkscreen](#section-id-93)
  - [Standards & QC](#section-id-96)
- [PCB Assembly](#section-id-103)
  - [Placement](#section-id-114)
  - [Solder Paste](#section-id-129)
  - [Solder Wire](#section-id-138)
  - [Flux](#section-id-145)
  - [Flux Remover](#section-id-150)
  - [Low Melt Alloy](#section-id-157)
  - [Solder Wick](#section-id-162)
  - [Heat](#section-id-167)
- [PCBA Processes](#section-id-180)
  - [Solder through hole components with soldering iron](#section-id-183)
  - [Solder SMT components with soldering iron](#section-id-186)
  - [Solder SMT components with hot air](#section-id-189)
  - [Solder SMT components with oven](#section-id-192)
  - [Solder SMT components with skillet](#section-id-195)
  - [Solder BGA components](#section-id-198)
  - [Rework through hole components](#section-id-201)
  - [Rework SMT components](#section-id-209)
  - [Rework BGA components](#section-id-217)
  - [Create solder paste stencil](#section-id-220)
  - [Apply solder paste with solder paste mask](#section-id-228)
  - [Apply solder paste with syringe](#section-id-231)
  - [Apply solder paste with electronic syringe](#section-id-234)
  - [Solder Pot](#section-id-237)
- [PCBA Testing](#section-id-243)
- [Equipment](#section-id-246)
  - [LASER](#section-id-251)
  - [CNC](#section-id-262)
  - [3D Printer](#section-id-272)
  - [Solder Station](#section-id-282)
  - [Pick and Place](#section-id-309)
- [Production Boards](#section-id-319)
- [Copying / License](#section-id-328)
  


<div id='section-id-1'/>

# PCBA 
PCB Assembly. Soldering. SMT. Thru hole. Stencils. Paste. Equipment. Tools. HOWTOs.


This documents free software and open source hardware manufacturing
of PCBAs (Printed Circuit Board Assemblies).

Focus is particularly on tools that can be used with hackerspace-
level technology.

<div id='section-id-11'/>

# Software
Various Free Software (as defined by FSF) applications available
for the creation of PCBAs.

<div id='section-id-15'/>

## Debian
The below packages are in Debian Buster. Note, even though it is in
Debian, you may want to build some of these packages from scratch
since the version in Debian is old. Debian `backports` maintains
an up to date KiCAD.

The following Debian packages are in use in the current production toolchain:

* `freecad` --- Visualization of PCBAs and more. 3D CAD application.

* `inkscape` --- vector-based drawing program.

* `kicad` --- Electronic schematic and PCB design software.

The following Debian packages are NOT in use:

* `electronics-pcb` --- Debian packages for PCB development (meta package).

* `fritzing` --- Easy-to-use electronic design software.

* `geda` --- GPL EDA -- Electronics design software.

* `gerbv` --- Gerber file viewer.

* `lepton-eda` --- Lepton Electronic Design Automation.

* `pcb` --- printed circuit board (pcb) design program.

* `pcb2gcode` --- command-line tool for engraving PCBs using CNCs.

* `pcb-rnd` - Modular Printed Circuit Board layout tool.

* `visolate` - tool for engraving PCBs using CNCs.

<div id='section-id-49'/>

## Other Software
Other PCBA software available under Free Software licenses.

Used:

* J-Tech Photonics LASER Inkscape Plugin.

* `raster2gcode` --- Inkscape Plugin.

Not Used:

* `InteractiveHtmlBom` --- Interactive HTML BOM generation plugin for KiCad
https://github.com/openscopeproject/InteractiveHtmlBom

* `OpenPNP` --- Pick and Place software.

* [`flatcam`](http://flatcam.org/) --- Free and Open-source PCB CAM.
FlatCAM lets you take your designs to a CNC router. You can open Gerber, Excellon or G-code, edit it or create from scatch, and output G-Code. Isolation routing is one of many tasks that FlatCAM is perfect for.

<div id='section-id-68'/>

## Electronic Design Automation (EDA)
To design PCBs, KiCAD is used.
Export Gerber files for manufacturing.

<div id='section-id-72'/>

# PCB Manufacturing
You can make your own PCB or have them made by numerous suppliers.
Recommended suppliers (amongst many):

* OSHPark --- Strong FLO supporters, high quality, quick turn, USA.

* DirtyPCBs --- Lowest possible cost out of Shenzhen, China.

* ProtoExpress -- Quick turn, high quality, high cost, USA.

* Many others that also support KiCAD!

<div id='section-id-84'/>

## Board Types and Features
FR1, FR4, etc.

<div id='section-id-87'/>

## Copper Layer
Cu later.

<div id='section-id-90'/>

## Soldermask
Green...

<div id='section-id-93'/>

## Silkscreen
White...

<div id='section-id-96'/>

## Standards & QC
Standards:

* RoHS (no lead).

* cf. NASA Standards.

<div id='section-id-103'/>

# PCB Assembly
You can have a board assembled by a house such as ProtoExpress,
or you can assemble it yourself. There is an endless variety of
DIY approaches to this. This you have the PCB finished. You need to:

* Source components.

* Place components.

* Solder Components.

<div id='section-id-114'/>

## Placement
The many ways to place a part...

* Fingers.

* Tweezers.

* Vacuum.

* Pick and Place.

What method is used depends on the type and size of the part
and what equipment is available. We'll be working with SMT,
BGA, and through hole parts.

<div id='section-id-129'/>

## Solder Paste
To solder SMT parts to PCB.

In use:

* CHIPQUIK SMD291SNL50T3, 50g jar.

* Zeph ZeroLead, 96.5Sn / 3Ag /.5Cu, 10cc syringe.

<div id='section-id-138'/>

## Solder Wire
In use:

* Kester K1000D, no clean, no lead, 0.8mm.

* Kester Sn96.5Ag3.0Cu0.5, no clean, no lead, 0.8mm.

<div id='section-id-145'/>

## Flux
In use:

* Zephlux No Clean Flux, 14 gr. jar.

<div id='section-id-150'/>

## Flux Remover
But you just put flux on...

In use:

* Zeph Flux Remover.

<div id='section-id-157'/>

## Low Melt Alloy
To desolder, perchance.

* Zeph ZERO No Lead Low Melt.

<div id='section-id-162'/>

## Solder Wick
Solder wick, aka desoldering wire.

In use: variety sizes.

<div id='section-id-167'/>

## Heat
You need to melt that solder...

* Solder Iron.

* Skillet.

* Oven.

* Hot air pencil.

* Hot air bath.

<div id='section-id-180'/>

# PCBA Processes
Working with PCBs and components:

<div id='section-id-183'/>

## Solder through hole components with soldering iron
HOWTO solder through hole components to a PCB with soldering.

<div id='section-id-186'/>

## Solder SMT components with soldering iron
HOWTO Solder SMT components with soldering iron.

<div id='section-id-189'/>

## Solder SMT components with hot air
HOWTO Solder SMT components with hot air.

<div id='section-id-192'/>

## Solder SMT components with oven
HOWTO Solder SMT components with oven.

<div id='section-id-195'/>

## Solder SMT components with skillet
HOWTO Solder SMT components with skillet.

<div id='section-id-198'/>

## Solder BGA components
HOWTO Solder BGA components.

<div id='section-id-201'/>

## Rework through hole components
HOWTO Rework through hole components.

Current Practice:

* [Through Hole Component Removal HOWTO]
(HOWTO/through-hole-component-removal-HOWTO.md)

<div id='section-id-209'/>

## Rework SMT components
HOWTO Rework SMT components.

Current Practice:

* [SMT Component Removal HOWTO]
(HOWTO/smt-component-removal-HOWTO.md)

<div id='section-id-217'/>

## Rework BGA components
HOWTO Rework BGA components.

<div id='section-id-220'/>

## Create solder paste stencil
HOWTO Create solder paste stencil.

Current Practice:

* [HOWTO create a solder paste stencil with Inkscape]
(HOWTO/laser-solder-paste-stencil-inkscape.md)

<div id='section-id-228'/>

## Apply solder paste with solder paste mask
HOWTO Apply solder paste with solder paste mask.

<div id='section-id-231'/>

## Apply solder paste with syringe
HOWTO Apply solder paste with syringe.

<div id='section-id-234'/>

## Apply solder paste with electronic syringe
HOWTO Apply solder paste with electronic syringe.

<div id='section-id-237'/>

## Solder Pot
HOWTO Use a solder pot.

* [Solder Pot HOWTO]
(HOWTO/solder-pot-HOWTO.md) 

<div id='section-id-243'/>

# PCBA Testing
Pins.

<div id='section-id-246'/>

# Equipment
The equipment considered is what is generally available to
hackerspaces. This leaves out industrial gear like large
wave solder machines.

<div id='section-id-251'/>

## LASER
LASERS can serve a few purposes in manufacturing PCBAs.
Inexpensive LASER cutters are available at many hackerspaces.
Inexpensive LASERs can be retrofit to RepRap 3D printers.

* Cut solder paste stencils.

* Etch paint, which is then chemically etched.

* Board marking, such as serialization.

<div id='section-id-262'/>

## CNC
Large CNCs are overkill for PCBA assembly.
Very small CNCs can be used.
CNCs are available at many hackerspaces.
CNCs can be used to:

* Engrave PCB.

* Drill PCB holes.

<div id='section-id-272'/>

## 3D Printer
RepRap 3D printers are available at many hackerspaces.
3D printers can be used to:

* Make CNC fixtures.

* Make board holding fixtures.

* Make other tools, etc.

<div id='section-id-282'/>

## Solder Station
Solder station tools:

* Soldering iron.

* Hot air pencil.

* Hot air bath.

* Fume extrator.

* PCB holder.

* Lights.

* Magnification.

* Solder paste dispenser.

* Vacuum pencil.

* Oven.

* Heat plate.

* Solder pot.

<div id='section-id-309'/>

## Pick and Place
A variety of free software compatible and open source hardware
pick and place machines are available.

* OpenPNP designs.

* LitePlacer. Note, works with Free Software OpenPNP, but is
non-commercial design licensed hardware. Manufacturer supplies
proprietary application.

<div id='section-id-319'/>

# Production Boards
Boards manufactured or slated to be manufactured.

* Trellisboard --- Ultimate ECP5 board.
https://code.forksand.com/forksand/fs-TrellisBoard

* ULX3X --- ECP5 board.
https://code.forksand.com/forksand/fs-ulx3s

<div id='section-id-328'/>

# Copying / License
This document is available here:
https://code.forksand.com/forksand/pcba/src/branch/master/README.md

License: CC By SA 4.0 International and/or GPLv3+ at your discretion.
Other code licensed under their own respective licenses.

Copyright © 2019, Fork Sand, Inc.

